@@ -7,7 +7,7 @@ use Scalar::Util qw(reftype);
 
 use Carp;
 
-our $VERSION = '0.04';
+our $VERSION = '0.10';
 our @EXPORT_OK = qw(bind_named);
 
 sub bind_named {
@@ -20,7 +20,7 @@ sub bind_named {
 
 	my $bind = [];
 
-	$sql =~ s{:(\w+)}{
+	$sql =~ s{:([A-Za-z_][A-Za-z0-9_]*)}{
 		croak("'$1' does not exist in bind hash") if !exists $hash->{$1};
 		my $type = ref($hash->{$1});
 		if ($type eq 'ARRAY') {
